'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactVirtualized = require('react-virtualized');

var _RowSelection = require('../RowSelection');

var _RowSelection2 = _interopRequireDefault(_RowSelection);

var _NoRows = require('../NoRows');

var _NoRows2 = _interopRequireDefault(_NoRows);

var _ListGrid = require('./ListGrid.scss');

var _ListGrid2 = _interopRequireDefault(_ListGrid);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * List renderer that accepts a custom row renderer.
 * The row renderer will create a row element for each collection item.
 */
function ListGrid(props) {
	var children = props.children,
	    collection = props.collection,
	    id = props.id,
	    height = props.height,
	    isActive = props.isActive,
	    isSelected = props.isSelected,
	    onRowClick = props.onRowClick,
	    rowHeight = props.rowHeight,
	    rowRenderer = props.rowRenderer,
	    width = props.width;


	var enhancedRowRenderer = rowRenderer;
	if (isActive || isSelected) {
		enhancedRowRenderer = (0, _RowSelection2.default)(rowRenderer, {
			isActive: isActive,
			isSelected: isSelected,
			getRowData: function getRowData(_ref) {
				var index = _ref.index;
				return collection[index];
			}
		});
	}

	return _react2.default.createElement(
		_reactVirtualized.List,
		{
			className: _ListGrid2.default['tc-list-list'],
			collection: collection,
			id: id,
			height: height,
			overscanRowCount: 10,
			onRowClick: onRowClick,
			noRowsRenderer: _NoRows2.default,
			rowCount: collection.length,
			rowHeight: rowHeight,
			rowRenderer: enhancedRowRenderer,
			rowGetter: function rowGetter(index) {
				return collection[index];
			},
			width: width
		},
		children
	);
}

ListGrid.displayName = 'VirtualizedList(ListGrid)';
ListGrid.propTypes = {
	children: _react.PropTypes.arrayOf(_react.PropTypes.element),
	collection: _react.PropTypes.arrayOf(_react.PropTypes.object),
	height: _react.PropTypes.number,
	id: _react.PropTypes.string,
	isActive: _react.PropTypes.func,
	isSelected: _react.PropTypes.func,
	onRowClick: _react.PropTypes.func,
	rowHeight: _react.PropTypes.number,
	rowRenderer: _react.PropTypes.func,
	width: _react.PropTypes.number
};

ListGrid.defaultProps = {
	rowHeight: 135
};

exports.default = ListGrid;